==> haskell-cassava-megaparsec-2.0.4-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cassava-megaparsec
version:              2.0.4
visibility:           public
id:                   cassava-megaparsec-2.0.4-E5HuuCZTfNyLn88gbyQUPR
key:                  cassava-megaparsec-2.0.4-E5HuuCZTfNyLn88gbyQUPR
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  98a6ca17c0a1e276dea7a6f001a92c6d
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cassava-megaparsec-2.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cassava-megaparsec-2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.0.4-E5HuuCZTfNyLn88gbyQUPR
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cassava-0.5.3.0-JBMy0FmgnH2EW83NS6exnK
    megaparsec-9.3.0-AtMuzV1F8g37Q0K0OvzWGi
    unordered-containers-0.2.19.1-8VYAOBvAPnuAGZDvxcTgvW
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.0.4-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cassava-megaparsec
version:              2.0.4
visibility:           public
id:                   cassava-megaparsec-2.0.4-BmPgDQCMND4IhHiRLevbPQ
key:                  cassava-megaparsec-2.0.4-BmPgDQCMND4IhHiRLevbPQ
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  c31fd106846d47df93c57653164feb82
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cassava-megaparsec-2.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cassava-megaparsec-2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.0.4-BmPgDQCMND4IhHiRLevbPQ
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cassava-0.5.3.0-IsekJ0pgU2EL1PkTBtnjMX
    megaparsec-9.3.0-AtMuzV1F8g37Q0K0OvzWGi
    unordered-containers-0.2.19.1-1oz2vTo8QZe9pPW8EMafVJ
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
